aboutsummaryrefslogtreecommitdiff
path: root/gcc/sched-ebb.c
diff options
context:
space:
mode:
authorKazu Hirata <kazu@cs.umass.edu>2003-07-01 12:18:01 +0000
committerKazu Hirata <kazu@gcc.gnu.org>2003-07-01 12:18:01 +0000
commite0bb17a83f613106571d3b516168d12cf83b10be (patch)
tree2e247fb1aad8f72881cfd082e69ebe412ba7989f /gcc/sched-ebb.c
parent0d0a1710d97a7eff97667caa55f83cc7bbe948de (diff)
downloadgcc-e0bb17a83f613106571d3b516168d12cf83b10be.zip
gcc-e0bb17a83f613106571d3b516168d12cf83b10be.tar.gz
gcc-e0bb17a83f613106571d3b516168d12cf83b10be.tar.bz2
basic-block.h: Fix comment typos.
* basic-block.h: Fix comment typos. * bb-reorder.c: Likewise. * c-format.c: Likewise. * cfgcleanup.c: Likewise. * cfghooks.h: Likewise. * cfgloop.c: Likewise. * cfgloopmanip.c: Likewise. * cfgrtl.c: Likewise. * cgraph.h: Likewise. * cgraphunit.c: Likewise. * combine.c: Likewise. * convert.c: Likewise. * dbxout.c: Likewise. * df.c: Likewise. * df.h: Likewise. * diagnostic.c: Likewise. * dwarf2out.c: Likewise. * et-forest.h: Likewise. * flow.c: Likewise. * fold-const.c: Likewise. * function.h: Likewise. * gcov-io.h: Likewise. * gcov.c: Likewise. * gcse.c: Likewise. * genautomata.c: Likewise. * ggc-common.c: Likewise. * ggc-page.c: Likewise. * loop-unroll.c: Likewise. * loop-unswitch.c: Likewise. * loop.c: Likewise. * mips-tfile.c: Likewise. * optabs.c: Likewise. * ra-build.c: Likewise. * ra-colorize.c: Likewise. * ra-rewrite.c: Likewise. * ra.h: Likewise. * regmove.c: Likewise. * reload.c: Likewise. * rtlanal.c: Likewise. * sched-ebb.c: Likewise. * sched-int.h: Likewise. * sched-vis.c: Likewise. * sreal.c: Likewise. * ssa-ccp.c: Likewise. * ssa.c: Likewise. * toplev.c: Likewise. * tree-inline.c: Likewise. * value-prof.c: Likewise. * value-prof.h: Likewise. From-SVN: r68770
Diffstat (limited to 'gcc/sched-ebb.c')
-rw-r--r--gcc/sched-ebb.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/sched-ebb.c b/gcc/sched-ebb.c
index 890a816..d27630e 100644
--- a/gcc/sched-ebb.c
+++ b/gcc/sched-ebb.c
@@ -206,7 +206,7 @@ static struct sched_info ebb_sched_info =
0, 1
};
/* It is possible that ebb scheduling elliminated some blocks.
Place blocks from FIRST to LAST before BEFORE. */
static void
@@ -268,7 +268,7 @@ fix_basic_block_boundaries (bb, last, head, tail)
last_inside = insn;
}
/* Control flow instruction terminate basic block. It is possible
- that we've elliminated some basic blocks (made them empty).
+ that we've eliminated some basic blocks (made them empty).
Find the proper basic block using BLOCK_FOR_INSN and arrange things in
a sensible way by inserting empty basic blocks as needed. */
if (control_flow_insn_p (insn) || (insn == tail && last_inside))
@@ -303,7 +303,7 @@ fix_basic_block_boundaries (bb, last, head, tail)
h = curr_bb->head;
curr_bb->head = head;
curr_bb->end = insn;
- /* Edge splitting created missplaced BASIC_BLOCK note, kill
+ /* Edge splitting created misplaced BASIC_BLOCK note, kill
it. */
delete_insn (h);
}
@@ -453,7 +453,7 @@ add_deps_for_risky_insns (head, tail)
case TRAP_RISKY:
case IRISKY:
case PRISKY_CANDIDATE:
- /* ??? We could implement better checking PRISKY_CANDIATEs
+ /* ??? We could implement better checking PRISKY_CANDIDATEs
analogous to sched-rgn.c. */
/* We can not change the mode of the backward
dependency because REG_DEP_ANTI has the lowest
@@ -206,7 +206,7 @@ static struct sched_info ebb_sched_info =
0, 1
};
-/* It is possible that ebb scheduling elliminated some blocks.
+/* It is possible that ebb scheduling eliminated some blocks.
Place blocks from FIRST to LAST before BEFORE. */
static void